@@ -10,9 +10,6 @@ describe 'heat' do
   let :params do
     {
       :package_ensure        => 'present',
-      :debug                 => 'False',
-      :use_stderr            => 'True',
-      :log_dir               => '/var/log/heat',
       :database_connection   => 'mysql+pymysql://user@host/database',
       :database_idle_timeout => 3600,
       :flavor                => 'keystone',
@@ -57,7 +54,6 @@ describe 'heat' do
 
   shared_examples_for 'a heat base installation' do
 
-    it { is_expected.to contain_class('heat::logging') }
     it { is_expected.to contain_class('heat::params') }
 
     it 'installs heat common package' do
@@ -120,10 +116,6 @@ describe 'heat' do
       is_expected.to contain_heat_config('trustee/password').with_secret( true )
     end
 
-    it 'configures auth_uri for clients_keystone' do
-      is_expected.to contain_heat_config('clients_keystone/auth_uri').with_value( 'http://127.0.0.1:5000/' )
-    end
-
     it 'configures endpoint_type for clients' do
       is_expected.to contain_heat_config('clients/endpoint_type').with_value( '<SERVICE DEFAULT>' )
     end
@@ -427,11 +419,6 @@ describe 'heat' do
     end
   end
 
-  shared_examples_for "with custom heat_clients_keystone_uri" do
-      before { params.merge!( :heat_clients_keystone_uri => 'https://domain1/' ) }
-      it { is_expected.to contain_heat_config('clients_keystone/auth_uri').with_value('https://domain1/') }
-  end
-
   on_supported_os({
     :supported_os   => OSDefaults.get_supported_os
   }).each do |os,facts|
